/*
 *   setmix - Audio Mixer Setup Program
 *
 *   Author: Gaspar Sinai (gsinai@gol.com) 
 *   Copyright (C) 1996  Gaspar Sinai
 * 
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   This program is setting the mixer values from a dump file created
 *   by either this program or xmmix. It is useful if you want to save 
 *   the setting for users logging in and out at the console. They can 
 *   receive  their own defults of sound setting.
 * 
 *   Many thanks to Ti Kan (ti@amb.org) who made xmmix available. Most
 *   of the code in this program is based upon that excellent application.
 *
 *   xmmix is a GNU Copyrighted Software of Ti Kan.
 */

#ifndef __setmix_h_
#define __setmix_h_

#include <sys/soundcard.h>
#include <sys/types.h>
#include <unistd.h> /* If you have one */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <signal.h>
#include <linux/fcntl.h>

#ifndef FILENAME_MAX
#	define FILENAME_MAX 1024
#endif


#define FALSE ((bool_t)0)
#define TRUE (!FALSE)


#define MAXDEVS		32	/* Max devices supported */
#define MAXDEVS_V2	12	/* VoxWare 2.x SOUND_MIXER_NRDEVICES */
#define MAXDEVS_V3	17	/* USS/VoxWare 3.x SOUND_MIXER_NRDEVICES */

/* Ioctl data direction flags */
#define IOC_DATA_NONE   0
#define IOC_DATA_IN     1
#define IOC_DATA_OUT    2

/* Buffer size for strings */
#define STR_BUF_SZ 		1024

typedef char           bool_t; 

/* Structure of control state information */
typedef struct {
	int		devmask;	/* Mixer feature mask */
	int		recmask;	/* Recording source capability mask */
	int		recsrc;		/* Recording source selector */
	int		stereodevs;	/* Stereo source capability mask */
	int		caps;		/* Capability flags */
	int		enhance;       	/* Stereo enhance setting */
	int		mute;		/* Mute setting */
	int		loudness;	/* Loudness setting */
	struct {
		int	left;		/* Left slider setting */
		int	right;		/* Right slider setting */
		bool_t	locked;		/* Sliders locked */
		char	*name;		/* Name of the slider */
	} slinfo[MAXDEVS];
} ctlinfo_t;


/*
 *  I want to put all mess in the include files
 */
#ifdef __setmix_h_

/* Could have used SOUND_DEVICE_NAMES but the cahnce that that would chnage
   is much higher than a definition number change. So the map bellow arguably
   hardcodes the definitions in soundcard.h */

static ctlinfo_t	ctlinfo = {	/* State of all controls */
	0, 0, 0, -1, -1, -1, FALSE, FALSE,
	{
		{  -1,  -1, TRUE, "master" },	/* 0 */
		{ 50, 50, TRUE, "bass" },	/* 1 */
		{ 50, 50, TRUE, "treble" },	/* 2 */
		{  -1,  -1, TRUE, "synth" },	/* 3 */
		{  -1,  -1, TRUE, "pcm" },	/* 4 */
		{  -1,  -1, TRUE, "speaker" },	/* 5 */
		{  -1,  -1, TRUE, "line" },	/* 6 */
		{  -1,  -1, TRUE, "mic" },	/* 7 */
		{  -1,  -1, TRUE, "cd" },	/* 8 */
		{  -1,  -1, TRUE, "recmon" },	/* 9 */
		{  -1,  -1, TRUE, "altpcm" },	/* 10 */
		{  -1,  -1, TRUE, "recout" },	/* 11 */
		{  -1,  -1, TRUE, "igain" },	/* 12 */
		{  -1,  -1, TRUE, "ogain" },	/* 13 */
		{  -1,  -1, TRUE, "line1" },	/* 14 */
		{  -1,  -1, TRUE, "line2" },	/* 15 */
		{  -1,  -1, TRUE, "line3" },	/* 16 */
		{  -1,  -1, TRUE, NULL },	/* 17 */
		{  -1,  -1, TRUE, NULL },	/* 18 */
		{  -1,  -1, TRUE, NULL },	/* 19 */
		{  -1,  -1, TRUE, NULL },	/* 20 */
		{  -1,  -1, TRUE, NULL },	/* 21 */
		{  -1,  -1, TRUE, NULL },	/* 22 */
		{  -1,  -1, TRUE, NULL },	/* 23 */
		{  -1,  -1, TRUE, NULL },	/* 24 */
		{  -1,  -1, TRUE, NULL },	/* 25 */
		{  -1,  -1, TRUE, NULL },	/* 26 */
		{  -1,  -1, TRUE, NULL },	/* 27 */
		{  -1,  -1, TRUE, NULL },	/* 28 */
		{  -1,  -1, TRUE, NULL },	/* 29 */
		{  -1,  -1, TRUE, NULL },	/* 30 */
		{  -1,  -1, TRUE, NULL }	/* 31 */
	}
};

static bool_t init_mixer (char *device) ;
static bool_t deinit_mixer () ;
static bool_t load_mixer(char *path) ;
static bool_t write_mixer(char *path) ;
static int get_device();
static int set_device();
static int do_ioctl(int cmd, int *arg, char *name, int dir);
static void my_sighandler(int signal);


#endif /* __setmix_c */


#endif	/* __setmix_h_ */

